| checkConv | R Documentation |
Primarily internal code for checking optimization convergence, see convergence for a more detailed discussion.
checkConv(derivs, coefs, ctrl, lbound, ubound,
debug = FALSE, nobs = NULL, ndim = NULL)
derivs |
typically the "derivs" attribute of |
coefs |
current coefficient estimates |
ctrl |
list of lists, each with |
lbound, ubound |
vectors of lower and upper bounds for random-effects parameters only (length is taken to determine number of RE parameters) |
debug |
enable debugging output, useful if some checks are on "ignore", but would "trigger" |
nobs |
number of observations (needed to determine whether to do convergence checks for large data) |
ndim |
number of dimensions for the variance-covariance matrix of random effects (needed to determine whether to do the gradient/hessian checks for large nonlinear optimization problems) |
A result list containing
code |
The return code for the check |
messages |
A character vector of warnings and messages generated by the check |
convergence
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.