| cake | R Documentation |
Data on the breakage angle of chocolate cakes made with three different recipes and baked at six different temperatures. This is a split-plot design with the recipes being whole-units and the different temperatures being applied to sub-units (within replicates). The experimental notes suggest that the replicate numbering represents temporal ordering.
A data frame with 270 observations on the following 5 variables.
replicatea factor with levels 1 to 15
recipea factor with levels A, B and C
temperaturean ordered factor with levels 175
< 185 < 195 < 205 < 215 < 225
anglea numeric vector giving the angle at which the cake broke.
tempnumeric value of the baking temperature (degrees F).
The replicate factor is nested within the
recipe factor, and temperature is nested
within replicate.
Original data were presented in Cook (1938), and reported in Cochran and Cox (1957, p. 300). Also cited in Lee, Nelder and Pawitan (2006).
cook1938chocolatelme4
cochran1957experimentallme4
lee2006generalizedlme4
str(cake)
## 'temp' is continuous, 'temperature' an ordered factor with 6 levels
(fm1 <- lmer(angle ~ recipe * temperature + (1|recipe:replicate), cake, REML= FALSE))
(fm2 <- lmer(angle ~ recipe + temperature + (1|recipe:replicate), cake, REML= FALSE))
(fm3 <- lmer(angle ~ recipe + temp + (1|recipe:replicate), cake, REML= FALSE))
## and now "choose" :
anova(fm3, fm2, fm1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.