Learn R Programming

lme4 (version 1.1-19)

golden-class: Class "golden" and Generator for Golden Search Optimizer Class

Description

"golden" is a reference class for a golden search scalar optimizer, for a parameter within an interval.

golden() is the generator for the "golden" class. The optimizer uses reverse communications.

Usage

golden(...)

Arguments

…

(partly optional) arguments passed to new() must be named arguments. lower and upper are the bounds for the scalar parameter; they must be finite.

Extends

All reference classes extend and inherit methods from "'>envRefClass".

Examples

Run this code
# NOT RUN {
showClass("golden")

golden(lower= -100, upper= 1e100)
# }

Run the code above in your browser using DataLab