| gopherdat2 | R Documentation |
Data of fresh Gopher tortoise shell remains \insertCiteozgul2009upperlme4.
data("gopherdat2")
A data frame with 30 observations on the following 7 variables.
Sitea factor representing the sampling site. There are
10 levels:
BS (Big Shoals State Park).
CB (Camp Blanding Wildlife Management Area).
Cent (privately-owned property in central Florida).
CF (Cecil Field/Branan Field Wildlife and Environmental
Area).
FC (Fort Cooper State Park).
FE (Flying Eagle Wildlife Management Area).
GH (Gold Head Branch State Park).
Old (Perry Oldenburg Wildlife and Environmental Area).
Ord (Ordway-Swisher Biological Station).
TE (Tenoroc Fish Management Area).
yeara numeric vector of the sampling year.
shellsa numeric vector of the number of shells found.
Areaa numeric vector representing site area (units unknown).
densitya numeric vector representing population density.
preva numeric vector representing the seroprevalence (frequency of antibodies to disease) of M. agassizi.
Details of the study is described in \insertCiteozgul2009upperlme4 as follows: "The fieldwork was conducted between 2003 and 2006, during late spring/summer (May–September). Systematic surveys were conducted to locate tortoise burrows and shell remains from deceased tortoises at study sites and consisted of a line of four to eight observers spaced 10 m apart walking parallel transects across the study area."
ozgul2009upperlme4
ozgul2009upperlme4
## Simple model gives a singular fit:
gopher_glmer <- glmer(shells ~ factor(year) + prev + offset(log(Area))
+ (1|Site), data = gopherdat2, family = "poisson")
## The site-level variance for this model is indeed zero:
VarCorr(gopher_glmer)
## So a Poisson GLM gives the same answer here:
gopher_glm <- glm(shells ~ factor(year) + prev + offset(log(Area)),
data = gopherdat2, family = "poisson")
all.equal(fixef(gopher_glmer), coef(gopher_glm))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.