| reformulas_imports | R Documentation |
Formula-processing functions that have moved to reformulas
subbars(...)
nobars(...)
findbars(...)
mkReTrms(...)
isNested(...)
expandDoubleVerts(...)
reOnly(...)
... |
arguments to be passed through to functions in the
|
All of these functions are now located in the reformulas
package. The versions here are 'shims' that throw a warning and
call the reformulas version. (reOnly will not be
fully fixed in reformulas until version 0.4.5 is on CRAN.)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.