| schizophrenia | R Documentation |
In the NIMH Schizophrenia Collaborative Study, patients were randomized to receive one of four medications, either placebo or one of three different anti-psychotic drugs. The protocol indicated subjects were to then be evaluated at weeks 0, 1, 3, 6 to assess severity of illness; additionally some measurements were made at weeks 2, 4, and 5.
data(schizophrenia)
A data frame with 1603 observations on the following 9 variables.
ida numeric vector indicating the unique patient identifier.
imps79a numeric vector from item 79 on the Inpatient Multidimensional Psychiatric Scale indicating severity of illness. The scores were applied to be interpreted as follows:
1 = normal, not ill at all,
2 = borderline mentally ill,
3 = mildly ill,
4 = moderately ill,
5 = markedly ill,
6 = severely ill,
7 = among the most extremely ill.
imps79ba binary version of imps79.
imps79oan ordinally scaled version of imps79.
inta numeric vector of ones; used in stand-alone package to indicate intercept.
TxDruga numeric vector indicating treatment with drug
1 or placebo 0.
Weeka numeric vector indicating time, in weeks.
SqrtWeekthe square root of the Week variable.
TxSWeeka variable representing the TxDrug * Week
interaction.
This data and most of this documentation was taken from the mixor package, which is no longer from CRAN. The references below mostly reference the deprecated mixor program.
hedeker1996mixorlme4
hedeker2006longitudinallme4
schmod <- glmer(imps79 ~ TxDrug * Week + (1 | id),
data = schizophrenia, family = Gamma(link = "log"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.